@@ -151,12 +151,12 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"client.protocol", "n|i|n|n|n|n|n|n|n|n", NULL, 0, NULL},
     {"client.direct", "t|t|t|t|t|t|t|t|t|t", NULL, 0, NULL},
     {"client.connCmd", "telnet nngs.cosmic.org 9696|"
-       "telnet igs.nuri.net 6969|"
+       "telnet igs.joyjoy.net 6969|"
        "telnet|telnet|telnet|telnet|telnet|telnet|telnet|telnet",
        NULL, 0, NULL},
     {"client.username", "|||||||||", NULL, 0, NULL},
     {"client.password", "|||||||||", NULL, 0, NULL},
-    {"client.address", "nngs.cosmic.org|igs.nuri.net|micro.ee.nthu.edu.tw|"
+    {"client.address", "nngs.cosmic.org|igs.joyjoy.net|micro.ee.nthu.edu.tw|"
        "jet.ncic.ac.cn|grizu.uni-regensburg.de|||||",
        NULL, 0, NULL},
     {"client.port", "9696|6969|9696|9696|9696|9696|9696|9696|9696|9696",
