@@ -19,7 +19,7 @@
 #include <but/canvas.h>
 #include <but/ctext.h>
 #ifdef  _CLIENT_GAME_H_
-        LEVELIZATION ERROR
+#error LEVELIZATION ERROR
 #endif
 #include "game.h"
 
@@ -951,9 +951,9 @@ static ButOut  listPressed(But *but, int line)  {
 }
 
 
-bool  cliGame_tellIsSay(CliGameList *list, Str *tell)  {
-  const char  tellerName[41];
-  int  matches;
+bool cliGame_tellIsSay(CliGameList *list, Str *tell)  {
+  char tellerName[41];
+  int matches;
 
   if (list->playGame >= 0)  {
     matches = sscanf(str_chars(tell), "*%40[^*]", tellerName);
